﻿using System;
using System.Collections.Generic;
using System.ComponentModel.DataAnnotations;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace IRaCIS.Core.Domain.Share.Reading
{
    /// <summary>
    /// 模块枚举
    /// </summary>
    public enum ModuleTypeEnum
    {
        /// <summary>
        /// 计划内访视
        /// </summary>
        InPlanSubjectVisit=0,

        /// <summary>
        /// 计划外访视
        /// </summary>
        OutPlanSubjectVisit = 1,

        /// <summary>
        /// 阅片期
        /// </summary>
        Read = 2,

        /// <summary>
        /// 全局阅片
        /// </summary>
        Global = 3,

        /// <summary>
        /// 裁判
        /// </summary>
        Referee = 4,

        /// <summary>
        /// 肿瘤学
        /// </summary>
        Oncology = 5,

      
    }

    public enum ReadingSetType
    {
        /// <summary>
        /// 影像阅片
        /// </summary>
        ImageReading=0,

        /// <summary>
        /// 肿瘤阅片
        /// </summary>
        TumorReading=1,
    }

    /// <summary>
    /// 阅片期范围
    /// </summary>
    public enum ReadingScopeEnum
    {
        /// <summary>
        /// 全部
        /// </summary>
        All=0,

        /// <summary>
        /// 根据Site
        /// </summary>
        Site=1,
    }





    /// <summary>
    /// 状态
    /// </summary>
    public enum ReadingPeriodStatus
    {
        /// <summary>
        /// 未生效
        /// </summary>
        NotTakeEffect=0,

        /// <summary>
        /// 已生效
        /// </summary>
        TakeEffect = 1,

        /// <summary>
        /// 已撤销
        /// </summary>
        Revocation=2,
    }

    /// <summary>
    /// 阅片模块状态
    /// </summary>
    public enum ReadModuleEnum
    {
        /// <summary>
        /// 影像上传
        /// </summary>
        ImageUpload=0,

        /// <summary>
        /// 影像质控
        /// </summary>
        ImageQuality = 1,

        /// <summary>
        /// 一致性核查
        /// </summary>
        ConsistencyCheck = 2,

        /// <summary>
        /// 任务分配
        /// </summary>
        TaskAllocation = 3,

        /// <summary>
        /// 影像阅片
        /// </summary>
        ImageRead = 4,

        /// <summary>
        /// 阅片完成
        /// </summary>
        ReadComplete = 5,

    }


    /// <summary>
	/// 上传方式
	/// </summary>
	public enum ClinicalUploadType
    {
        /// <summary>
        /// PDF
        /// </summary>
        [Display(Name = "PDF")]
        PDF = 0,

        /// <summary>
        /// 表格
        /// </summary>
        [Display(Name = "表格")]
        Table = 1,

    }

    /// <summary>
    /// 数据类型
    /// </summary>
    public enum ClinicalDataType
    {
        /// <summary>
        /// 既往局部治疗史
        /// </summary>
        MedicalHistory = 0,

        /// <summary>
        /// 影像模态（PET临床信息）
        /// </summary>
        PET = 1,

        /// <summary>
        /// 胸水
        /// </summary>
        Hydrothorax = 2,
    }

    /// <summary>
    /// 临床分组级别
    /// </summary>
    public enum ClinicalLevel
    {
        /// <summary>
        /// 受试者
        /// </summary>
        [DisplayAttribute(Name ="受试者")]
        Subject = 0,

        /// <summary>
        /// 访视
        /// </summary>
        [DisplayAttribute(Name = "访视")]
        SubjectVisit = 1,

        /// <summary>
        /// 阅片
        /// </summary>
        [DisplayAttribute(Name = "阅片")]
        Read = 2,
    }

    /// <summary>
    /// 阅片状态
    /// </summary>
    public enum ReadingStatusEnum
    {
        None=0,
    }
}
